@@ -5,6 +5,7 @@ use Exporter qw/import/;
 
 our @EXPORT_OK = qw(
     datetime
+    game_result
 );
 
 sub datetime {
@@ -21,4 +22,16 @@ sub datetime {
             $hour, $min;
 }
 
+sub game_result {
+    my $result = shift;
+
+    return 'W+Resign' if $result eq 'W+Res.';
+    return 'B+Resign' if $result eq 'B+Res.';
+    return 'W+Forfeit' if $result eq 'W+Forf.';
+    return 'B+Forfeit' if $result eq 'B+Forf.';
+    return 'Draw' if $result eq 'Jigo';
+
+    $result;
+}
+
 1;
